@@ -246,14 +246,14 @@ namespace lsvpd
 
 	/**
 	 * pack serializes this object into the provided buffer (pack will
-	 *	allocate the buffer) storing only the data fields (at the moment)
-	 *	and ignoring all the meta-data within the DataItem object.
-	 *	The format for the packed object will be direct strings seperated
-	 *	by '\0' charaters.  If a given string field is empty then there will
-	 *	be consectutive '\0' characters.  Each of the vector fields will be
-	 *	preceeded by ::listNameStart:: and followed by ::listNameEnd::
-	 *	(e.g. the children vector will be
-	 *		::childrenStart::\0data\0data\0::childrenEnd::\0).
+	 * 	allocate the buffer) storing only the data fields (at the moment)
+	 * 	and ignoring all the meta-data within the DataItem object.
+	 * 	The format for the packed object will be direct strings seperated
+	 * 	by '\0' charaters.  If a given string field is empty then there will
+	 * 	be consectutive '\0' characters.  Each of the vector fields will be
+	 * 	preceeded by ::listNameStart:: and followed by ::listNameEnd::
+	 * 	(e.g. the children vector will be
+	 * 		::childrenStart::\0data\0data\0::childrenEnd::\0).
 	 */
 	unsigned int Component::pack( void** buffer )
 	{
@@ -697,14 +697,9 @@ namespace lsvpd
 			while( DEVICE_END != item )
 			{
 				DataItem* d = new DataItem( next );
-				if ( d == NULL ) {
-					VpdException ve( "Out of memory." );
-					throw ve;
-				}
 				next += d->getPackedLength( );
 				if( next > packed + size )
 				{
-					delete ( d );
 					goto lderr;
 				}
 				mDeviceSpecific.push_back( d );
@@ -725,14 +720,9 @@ namespace lsvpd
 			while( USER_END != item )
 			{
 				DataItem* d = new DataItem( next );
-				if ( d == NULL ) {
-					VpdException ve( "Out of memory." );
-					throw ve;
-				}
 				next += d->getPackedLength( );
 				if( next > packed + size )
 				{
-					delete ( d );
 					goto lderr;
 				}
 				mUserData.push_back( d );
@@ -752,14 +742,9 @@ namespace lsvpd
 			while( AX_END != item )
 			{
 				DataItem* d = new DataItem( next );
-				if ( d == NULL ) {
-					VpdException ve( "Out of memory." );
-					throw ve;
-                                }
 				next += d->getPackedLength( );
 				if( next > packed + size )
 				{
-					delete ( d );
 					goto lderr;
 				}
 				mAIXNames.push_back( d );
@@ -849,7 +834,7 @@ lderr:
 	 */
 	bool Component::isChild(Component *child)
 	{
-		for (unsigned int i = 0; i < mChildren.size(); i++)
+		for (int i = 0; i < mChildren.size(); i++)
 			if (mChildren[i] == child->idNode.getValue())
 				return true;
 		return false;
@@ -864,7 +849,7 @@ lderr:
 	 */
 	bool Component::isChild(const string& child)
 	{
-		for (unsigned int i = 0; i < mChildren.size(); i++)
+		for (int i = 0; i < mChildren.size(); i++)
 			if (mChildren[i] == child)
 				return true;
 		return false;
@@ -937,6 +922,7 @@ lderr:
 		d->ac = ac;
 		d->humanName = humanName;
 		d->setValue( val, lvl, __FILE__, __LINE__ );
+#if 0
 
 		/*
 		 * There can be multiple records with the 'CL' key.
@@ -951,6 +937,7 @@ lderr:
 			if( (*i)->ac == ac )
 				return; //Failed to add - already present
 		}
+#endif
 
 		mDeviceSpecific.push_back( d );
 	}
@@ -982,7 +969,7 @@ lderr:
 		else
 			return NULL;
 	}
-
+		
 	void Component::addUserData( const string& ac, const string& humanName,
 		const string& val, int prefLvl = 1, bool clobber = false )
 	{
@@ -1013,22 +1000,21 @@ lderr:
 
 	void Component::addAIXName( const string& val, int prefLvl = 1 )
 	{
+		DataItem *d = new DataItem( );
 		vector<DataItem*>::const_iterator j, stop;
 		j = getAIXNames().begin();
 		stop =getAIXNames().end();
 
-		/* Already present - remove */
-		for (;j != stop; j++) {
-			if (val == (*j)->getValue())
-				return;
-		}
-
-		DataItem *d = new DataItem( );
 		if( d == NULL )
 		{
 			VpdException ve( "Out of memory." );
 			throw ve;
 		}
+		/* Already present - remove */
+		for (;j != stop; j++) {
+			if (val == (*j)->getValue())
+				return;
+		}
 
 		d->ac = "AX";
 		d->humanName = "AIX Name";
@@ -1042,7 +1028,7 @@ lderr:
 	bool Component::removeLeaf( int index )
 	{
 		vector<Component*>::iterator i = mLeaves.begin( );
-		if( index > ( int )mLeaves.size( ) )
+		if( index > mLeaves.size( ) )
 		{
 			return false;
 		}
